@@ -13,8 +13,10 @@
 #          (1)Output list data
 # v0.1.1 : 2021/04/01
 #          (1)Output DataFrame
+# v0.1.2 : 2021/05/06
+#          add frameNumber and check colume-fields location
+# v0.1.3 : 2021/05/06 revise dataFrame dtype
 #
-
 import serial
 import time
 import struct
@@ -47,7 +49,7 @@ class Pc3:
 	port = ""
 	hdr = header
 	u = unitS
-	
+	frameNumber = 0
 	# provide csv file dataframe
 	# real-time 
 	
@@ -58,7 +60,8 @@ class Pc3:
 	
 	# read from file for trace point clouds
 	fileName = ''
-	v6_col_names = ['time','fN','type','elv','azimuth','range' ,'doppler','snr','sx', 'sy', 'sz']
+	#v6_col_names = ['time','fN','type','elv','azimuth','range' ,'doppler','snr','sx', 'sy', 'sz'] # original
+	v6_col_names = ['time','fN','type','elv','azimuth','doppler','range' ,'snr','sx', 'sy', 'sz']
 	v7_col_names = ['time','fN','type','posX','posY','velX','velY','accX','accY','posZ','velZ','accZ','tid']
 	v8_col_names = ['time','fN','type','targetID']
 	
@@ -241,7 +244,7 @@ class Pc3:
 						self.hdr.frameNumber,self.hdr.subframeNumber,
 						self.hdr.chirpMargin,self.hdr.frameMargin,self.hdr.trackProcessTime,self.hdr.uartSendTime,
 						self.hdr.numTLVs,self.hdr.checksum) = struct.unpack('9I2H', sbuf)
-						
+						self.frameNumber = self.hdr.frameNumber
 					except:
 						if self.dbg == True:
 							print("(Header)Improper TLV structure found: ")
@@ -352,6 +355,7 @@ class Pc3:
 							sx  = ran * np.cos(elv) * np.sin(azi)
 							sy  = ran * np.cos(elv) * np.cos(azi)
 							v6df.append((self.hdr.frameNumber,'v6',elv,azi,dop,ran,snr,sx,sy,sz))
+							 
 						else:
 							v6.append((elv,azi,dop,ran,snr))
 						
@@ -399,7 +403,8 @@ class Pc3:
 					try:
 						(tid,posX,posY,posZ,velX,velY,velZ,accX,accY,accZ) = struct.unpack('I9f', sbuf)
 						if (df == 'DataFrame'):
-							v7df.append((self.hdr.frameNumber,'v6',posX,posY,posZ,velX,velY,velZ,accX,accY,accZ,tid))
+							v7df.append((self.hdr.frameNumber,'v7',posX,posY,posZ,velX,velY,velZ,accX,accY,accZ,tid))
+							 
 						else: 
 							v7.append((tid,posX,posY,posZ,velX,velY,velZ,accX,accY,accZ))
 							
@@ -455,7 +460,7 @@ class Pc3:
 					if (df == 'DataFrame'):
 						v8o = [self.hdr.frameNumber,'v8']
 						v8df = v8o.extend(v8)
-					
+						 
 					#return (True,v6,v7,v8) if (df == None) else self.list2df(True,v6df,v7df,v8df)
 					return self.list2df(True,v6df,v7df,v8df) if (df == 'DataFrame') else (True,v6,v7,v8)
 				
@@ -508,22 +513,20 @@ class Pc3:
 		
 		v6simOri = df[(df.type == 'v6')]
 		#print("-------------------v6sim------------:{:}".format(v6simOri.shape))
-		#self.v6simo = v6simOri.loc[:,['fN','elv','azimuth','range','doppler','snr']]
-		self.v6simo = v6simOri.loc[:,['fN','type','elv','azimuth','range' ,'doppler','snr','sx', 'sy', 'sz']]
+		
+		self.v6simo = v6simOri.loc[:,['fN','type','elv','azimuth','doppler','range' ,'snr','sx', 'sy', 'sz']] # in this case
 		self.v6simo['elv'] = self.v6simo['elv'].astype(float, errors = 'raise') 
 		
 		df7 = pd.read_csv(self.fileName, names = self.v7_col_names, skiprows = [0])  
 		
+		#------------- v7 sim ---------------
 		v7simc = df7[df7['type'] == 'v7']
 		self.v7simo  = v7simc.loc[:,['fN','type','posX','posY','velX','velY','accX','accY','posZ','velZ','accZ','tid']]
+		self.v7simo['posX'] = self.v7simo['posX'].astype(float, errors = 'raise') 
 		self.sim_startFN = df['fN'].values[0]
 		self.sim_stopFN  = df['fN'].values[-1]
-		'''
-		print("---------start frame number---------:{:}".format(self.sim_startFN))
-		print("---------stop  frame number---------:{:}".format(self.sim_stopFN))
-		print(self.v7simo)
-		print("-----v8sim data lib-----")
-		'''
+		
+		#------------- v8 sim ---------------
 		v8simc = df[df['type'] == 'v8']
 		self.v8simo  = v8simc.loc[:,['fN','type','elv']]
 		self.v8simo.columns = ['fN','type','targetID']
